#!/bin/bash
#
#
# SIROCCO
# Copyright (C) 2011 France Telecom
# Contact: sirocco@ow2.org
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
# USA
#
#  $Id: customizeGuestOS.sh 13 2011-06-14 21:21:51Z dangtran $
#
#


usage() {
cat << EOF
usage: $0 options

OPTIONS:
  --device device to mount
  --net customization option for network interface: Iface / mode / ip / netmask / gateway
  --hostname customization option : new Hostname of the VM
  --sshkey root public ssh key to install on the guest OS
  --userdata key value
EOF
}

device=
hostname=
sshkey=
net=

while [[ -n $1 ]]; do
        case "$1" in
                device)
                device="$2"
                shift 2
                ;;

                net)
                net="$2"
                shift 2
                ;;

                hostname)
                hostname="$2"
                shift 2
                ;;

                sshkey)
                sshkey=$2
                shift 2
                ;;

                userdata)
                echo $2 $3 >> /tmp/userdata-$$.cfg
                shift 3
                ;;

                *)
                usage
                exit 1
                ;;
  esac
done

if [[ -z $device ]]
then
     usage
     exit 1
fi

root=/mnt/disk$$
mkdir $root

LIMIT=10
counter=1

while [ "$counter" -le $LIMIT ]
do
	if [[ -n /dev/$device ]] 
	then
		break
	fi
	sleep 1
  	let "counter+=1"
done  

if [[ -z /dev/$device ]]
then
	echo cannot find /dev/$device
	exit 1
fi

mount /dev/$device $root

                
if [[ -n $hostname ]] 
then            
        echo $hostname >  $root/etc/hostname 
        sed -i "s/HOSTNAME/$hostname/g" $root/etc/dhcp/dhclient.conf 
fi              

if [[ -n $sshkey ]]
then            
        mkdir $root/root/.ssh
        echo $sshkey > $root/root/.ssh/authorized_keys2 
fi

if [[ -e /tmp/userdata-$$.cfg ]]
then
        mv /tmp/userdata-$$.cfg  $root/etc/userdata.cfg
fi   
     
umount $root
rmdir $root
                